Enum sp_std::sync::mpsc::TrySendError 1.0.0[−][src]
pub enum TrySendError<T> {
Full(T),
Disconnected(T),
}This enumeration is the list of the possible error outcomes for the
try_send method.
Variants
The data could not be sent on the sync_channel because it would require that
the callee block to send the data.
If this is a buffered channel, then the buffer is full at this time. If
this is not a buffered channel, then there is no Receiver available to
acquire the data.
This sync_channel’s receiving half has disconnected, so the data could not be
sent. The data is returned back to the callee in this case.